@@ -51,7 +51,7 @@ impl ClusterBuilder {
 
         let token = token.into_boxed_str();
 
-        let http_client = Client::new(token.clone());
+        let http_client = Client::new(token.to_string());
 
         let shard_config =
             ShardBuilder::new(token.clone(), intents).http_client(http_client.clone());
@@ -61,7 +61,7 @@ impl ClusterBuilder {
                 http_client,
                 shard_config: shard_config.0,
                 shard_scheme: ShardScheme::Auto,
-                queue: Arc::new(Box::new(LocalQueue::new())),
+                queue: Arc::new(LocalQueue::new()),
                 resume_sessions: HashMap::new(),
             },
             ShardBuilder::new(token, intents),
@@ -78,16 +78,13 @@ impl ClusterBuilder {
     /// [`ClusterStartErrorType::RetrievingGatewayInfo`]: super::ClusterStartErrorType::RetrievingGatewayInfo
     pub async fn build(mut self) -> Result<(Cluster, Events), ClusterStartError> {
         if (self.1).0.gateway_url.is_none() {
-            let gateway_url = (self.1)
-                .0
-                .http_client
-                .gateway()
-                .authed()
-                .await
-                .ok()
-                .map(|s| s.url);
+            let maybe_response = (self.1).0.http_client.gateway().authed().exec().await;
 
-            self = self.gateway_url(gateway_url);
+            if let Ok(response) = maybe_response {
+                let gateway_url = response.model().await.ok().map(|info| info.url);
+
+                self = self.gateway_url(gateway_url);
+            }
         }
 
         self.0.shard_config = (self.1).0;
@@ -206,7 +203,7 @@ impl ClusterBuilder {
     /// Refer to the [`queue`] module for more information.
     ///
     /// [`queue`]: crate::queue
-    pub fn queue(mut self, queue: Arc<Box<dyn Queue>>) -> Self {
+    pub fn queue(mut self, queue: Arc<dyn Queue>) -> Self {
         self.0.queue = Arc::clone(&queue);
         self.1 = self.1.queue(queue);
 
