@@ -50,23 +50,6 @@ impl Compression {
         self.inner.as_mut_slice()
     }
 
-    /// Immutable reference to the internal buffer slice.
-    ///
-    /// When compression is enabled this will immutably reference the inflater's
-    /// buffer.
-    ///
-    /// When compression is disabled this will immutably reference the standard
-    /// buffer.
-    pub fn buffer_slice_ref(&self) -> &[u8] {
-        #[cfg(feature = "compression")]
-        {
-            self.inner.buffer_ref()
-        }
-
-        #[cfg(not(feature = "compression"))]
-        self.inner.as_slice()
-    }
-
     /// Clear the inner buffer.
     pub fn clear(&mut self) {
         self.inner.clear();
